@@ -1,4 +1,4 @@
-from ref import backend_to_check
+from bt import backend_to_check
 
 
 def test_default():
