@@ -1,5 +1,5 @@
+from bt import backend_to_check, prog_check
 from pyscreenshot.util import use_x_display
-from ref import backend_to_check, prog_check
 
 if use_x_display():
     if prog_check(["import", "-version"]):
