@@ -1,3 +1,4 @@
+from bt import backend_to_check, check_import
 from pyscreenshot import FailedBackendError
 from pyscreenshot.util import (
     platform_is_linux,
@@ -6,7 +7,6 @@ from pyscreenshot.util import (
     py2,
     use_x_display,
 )
-from ref import backend_to_check, check_import
 
 try:
     from Xlib import display
@@ -15,7 +15,9 @@ except ImportError:
 
 # https://github.com/python-xlib/python-xlib/blob/master/examples/xrandr.py#L44
 def missing_RANDR():
-    if display:
+    if platform_is_osx():
+        return False
+    if not display:
         return False
     disp = display.Display()
     return not disp.has_extension("RANDR")
