@@ -1,5 +1,5 @@
+from bt import backend_to_check
 from pyscreenshot.util import platform_is_linux
-from ref import backend_to_check
 
 if not platform_is_linux():
 
