@@ -1,9 +1,10 @@
+#!/usr/bin/env python3
 import os
+from os.path import dirname, join
 from time import sleep
 
 import fabric
 from entrypoint2 import entrypoint
-from path import Path
 
 import vagrant
 
@@ -12,13 +13,14 @@ import vagrant
 
 # pip3 install fabric vncdotool python-vagrant entrypoint2
 
-DIR = Path(__file__).parent.parent.parent
+DIR = dirname(dirname(dirname(__file__)))
 
 
 class Options:
     halt = True
     recreate = True
     destroy = False
+    fast = False
 
 
 def wrapcmd(cmd, guiproc):
@@ -31,8 +33,12 @@ def wrapcmd(cmd, guiproc):
 
 def run_box(options, vagrantfile, cmds, guiproc):
     env = os.environ
-    env["VAGRANT_VAGRANTFILE"] = DIR / vagrantfile
-    env["VAGRANT_DOTFILE_PATH"] = DIR / ".vagrant_" + vagrantfile
+    env["VAGRANT_VAGRANTFILE"] = join(DIR, vagrantfile)
+    if vagrantfile != "Vagrantfile":
+        env["VAGRANT_DOTFILE_PATH"] = join(DIR, ".vagrant_" + vagrantfile)
+    else:
+        env["VAGRANT_DOTFILE_PATH"] = ""
+
     v = vagrant.Vagrant(env=env, quiet_stdout=False, quiet_stderr=False)
     status = v.status()
     state = status[0].state
@@ -48,9 +54,16 @@ def run_box(options, vagrantfile, cmds, guiproc):
     if state == "not_created":
         # install programs in box
         v.up()
+
         # restart box
         v.halt()
 
+        if not options.fast:
+            # go over first boot messages, tasks
+            v.up()
+            sleep(3 * 60)
+            v.halt()
+
     try:
         v.up()
 
@@ -74,12 +87,12 @@ def run_box(options, vagrantfile, cmds, guiproc):
                         pid = conn.run(cmd).stdout
                         sleep(1)
                     print(f"{guiproc} pid={pid}")
-                sleep(1)
+                sleep(5)
                 for cmd in cmds:
                     if options.recreate:
                         if "tox" in cmd:
                             cmd += " -r"
-                    conn.run(wrapcmd(cmd, guiproc))
+                    conn.run(wrapcmd(cmd, guiproc), echo=True, pty=True)
     finally:
         if options.halt:
             v.halt()
@@ -87,64 +100,91 @@ def run_box(options, vagrantfile, cmds, guiproc):
 
 config = {
     "server": ("Vagrantfile", ["tox"], "",),
-    "lubuntu.18.04": (
-        "Vagrantfile.lubuntu.18.04.rb",
-        ["tox -e py27-desktop", "tox -e py3-desktop"],
-        "lxsession",
+    "ubuntu.20.10.sway": (
+        "Vagrantfile.ubuntu.20.10.sway.rb",
+        ["tox -e py3-desktop"],
+        "kitty",
     ),
-    # TODO: add ubuntu 20.04 variants when it becomes stable
-    # "lubuntu.20.04": (
-    #     "Vagrantfile.lubuntu.20.04.rb",
+    "debian10.gnome.wayland": (
+        "Vagrantfile.debian10.gnome.wayland.rb",
+        # ["bash -c 'tox -e py3-desktop'"],
+        ["tox -e py3-desktop"],
+        "gnome-terminal-server",
+    ),
+    "debian10.gnome.x11": (
+        "Vagrantfile.debian10.gnome.x11.rb",
+        # ["bash -c 'tox -e py3-desktop'"],
+        ["tox -e py3-desktop"],
+        "gnome-terminal-server",
+    ),
+    "debian10.kde.wayland": (
+        "Vagrantfile.debian10.kde.wayland.rb",
+        ["tox -e py3-desktop"],
+        "konsole",
+    ),
+    "debian10.kde.x11": (
+        "Vagrantfile.debian10.kde.x11.rb",
+        ["tox -e py3-desktop"],
+        "konsole",
+    ),
+    # "lubuntu.18.04": (
+    #     "Vagrantfile.lubuntu.18.04.rb",
     #     ["tox -e py27-desktop", "tox -e py3-desktop"],
     #     "lxsession",
     # ),
-    "xubuntu.18.04": (
-        "Vagrantfile.xubuntu.18.04.rb",
-        ["tox -e py27-desktop", "tox -e py3-desktop"],
-        "xfdesktop",
+    "lubuntu.20.04": (
+        "Vagrantfile.lubuntu.20.04.rb",
+        ["tox -e py3-desktop"],
+        "qterminal",
     ),
-    # "xubuntu.20.04": (
-    #     "Vagrantfile.xubuntu.20.04.rb",
+    # "xubuntu.18.04": (
+    #     "Vagrantfile.xubuntu.18.04.rb",
     #     ["tox -e py27-desktop", "tox -e py3-desktop"],
     #     "xfdesktop",
     # ),
-    "kubuntu.18.04": (
-        "Vagrantfile.kubuntu.18.04.rb",
-        ["tox -e py27-desktop", "tox -e py3-desktop"],
-        "gnome-shell",
+    "xubuntu.20.04": (
+        "Vagrantfile.xubuntu.20.04.rb",
+        ["tox -e py3-desktop"],
+        "xfdesktop",
     ),
-    # "kubuntu.20.04": (
-    #     "Vagrantfile.kubuntu.20.04.rb",
+    # "kubuntu.18.04": (
+    #     "Vagrantfile.kubuntu.18.04.rb",
     #     ["tox -e py27-desktop", "tox -e py3-desktop"],
     #     "gnome-shell",
     # ),
-    "ubuntu.18.04": (
-        "Vagrantfile.ubuntu.18.04.rb",
+    "kubuntu.20.04": (
+        "Vagrantfile.kubuntu.20.04.rb",
         ["tox -e py3-desktop"],
-        "gnome-shell",
+        "konsole",
     ),
+    # "ubuntu.18.04": (
+    #     "Vagrantfile.ubuntu.18.04.rb",
+    #     ["tox -e py3-desktop"],
+    #     "gnome-shell",
+    # ),
     "ubuntu.20.04": (
         "Vagrantfile.ubuntu.20.04.rb",
         ["tox -e py3-desktop"],
         "gnome-shell",
     ),
-    "arch.kde.x11": (
-        "Vagrantfile.arch.kde.x11.rb",
-        ["tox -e py3-desktop"],
-        "plasma_session",
-    ),
-    "arch.kde.wayland": (
-        "Vagrantfile.arch.kde.wayland.rb",
-        ["tox -e py3-desktop"],
-        "plasma_session",
-        # "Xwayland",
-    ),
-    "arch.gnome.wayland": (
-        "Vagrantfile.arch.gnome.wayland.rb",
-        ["tox -e py3-desktop"],
-        "gnome-shell-calendar-server",
-        # "Xwayland",
-    ),
+    # "arch.kde.x11": (
+    #     "Vagrantfile.arch.kde.x11.rb",
+    #     ["tox -e py3-desktop"],
+    #     "plasmashell",
+    #     # "plasma_session",
+    # ),
+    # "arch.kde.wayland": (
+    #     "Vagrantfile.arch.kde.wayland.rb",
+    #     ["tox -e py3-desktop"],
+    #     "plasma_session",
+    #     # "Xwayland",
+    # ),
+    # "arch.gnome.wayland": (
+    #     "Vagrantfile.arch.gnome.wayland.rb",
+    #     ["tox -e py3-desktop"],
+    #     "gnome-shell-calendar-server",
+    #     # "Xwayland",
+    # ),
     # "win": ("Vagrantfile.win.rb", ["tox -e py3-win"], "",),
     "osx": (
         "Vagrantfile.osx.rb",
@@ -160,6 +200,7 @@ def main(boxes="all", fast=False, destroy=False):
     options.halt = not fast
     options.recreate = not fast
     options.destroy = destroy
+    options.fast = fast
 
     if boxes == "all":
         boxes = list(config.keys())
